# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401

from typing import List, Dict  # noqa: F401

from properly_model_python.search_models.models.base_model_ import Model
from properly_model_python.search_models import util
from properly_model_python.search_models.models.lat_lng import LatLng


class LatLngBounds(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, sw: LatLng=None, ne: LatLng=None):  # noqa: E501
        """LatLngBounds - a model defined in Swagger

        :param sw: The sw of this LatLngBounds.  # noqa: E501
        :type sw: LatLng
        :param ne: The ne of this LatLngBounds.  # noqa: E501
        :type ne: LatLng
        """
        self.swagger_types = {
            'sw': LatLng,
            'ne': LatLng
        }

        self.attribute_map = {
            'sw': 'sw',
            'ne': 'ne'
        }

        self._sw = sw
        self._ne = ne

    @classmethod
    def from_dict(cls, dikt) -> 'LatLngBounds':
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The LatLngBounds of this LatLngBounds.  # noqa: E501
        :rtype: LatLngBounds
        """
        return util.deserialize_model(dikt, cls)

    @property
    def sw(self) -> LatLng:
        """Gets the sw of this LatLngBounds.


        :return: The sw of this LatLngBounds.
        :rtype: LatLng
        """
        return self._sw

    @sw.setter
    def sw(self, sw: LatLng):
        """Sets the sw of this LatLngBounds.


        :param sw: The sw of this LatLngBounds.
        :type sw: LatLng
        """

        self._sw = sw

    @property
    def ne(self) -> LatLng:
        """Gets the ne of this LatLngBounds.


        :return: The ne of this LatLngBounds.
        :rtype: LatLng
        """
        return self._ne

    @ne.setter
    def ne(self, ne: LatLng):
        """Sets the ne of this LatLngBounds.


        :param ne: The ne of this LatLngBounds.
        :type ne: LatLng
        """

        self._ne = ne
