# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401

from typing import List, Dict  # noqa: F401

from properly_model_python.models.base_model_ import Model
from properly_model_python import util


class LatLng(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, lat: float=None, lng: float=None):  # noqa: E501
        """LatLng - a model defined in Swagger

        :param lat: The lat of this LatLng.  # noqa: E501
        :type lat: float
        :param lng: The lng of this LatLng.  # noqa: E501
        :type lng: float
        """
        self.swagger_types = {
            'lat': float,
            'lng': float
        }

        self.attribute_map = {
            'lat': 'lat',
            'lng': 'lng'
        }

        self._lat = lat
        self._lng = lng

    @classmethod
    def from_dict(cls, dikt) -> 'LatLng':
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The LatLng of this LatLng.  # noqa: E501
        :rtype: LatLng
        """
        return util.deserialize_model(dikt, cls)

    @property
    def lat(self) -> float:
        """Gets the lat of this LatLng.


        :return: The lat of this LatLng.
        :rtype: float
        """
        return self._lat

    @lat.setter
    def lat(self, lat: float):
        """Sets the lat of this LatLng.


        :param lat: The lat of this LatLng.
        :type lat: float
        """

        self._lat = lat

    @property
    def lng(self) -> float:
        """Gets the lng of this LatLng.


        :return: The lng of this LatLng.
        :rtype: float
        """
        return self._lng

    @lng.setter
    def lng(self, lng: float):
        """Sets the lng of this LatLng.


        :param lng: The lng of this LatLng.
        :type lng: float
        """

        self._lng = lng
