# coding: utf-8

# flake8: noqa
from __future__ import absolute_import
# import models into model package
from properly_model_python.models.custom_annotation import CustomAnnotation
from properly_model_python.models.image import Image
from properly_model_python.models.model_property import ModelProperty
from properly_model_python.models.room import Room
from properly_model_python.models.sold_property import SoldProperty
